diff Resources/CMake/BoostConfiguration.cmake @ 2781:13038d638097

primitives for android ndk
author Sebastien Jodogne <s.jodogne@gmail.com>
date Fri, 20 Jul 2018 11:01:33 +0200
parents ee9a6cd63891
children 64e3d4ab158d
line wrap: on
line diff
--- a/Resources/CMake/BoostConfiguration.cmake	Tue Jul 17 17:50:03 2018 +0200
+++ b/Resources/CMake/BoostConfiguration.cmake	Fri Jul 20 11:01:33 2018 +0200
@@ -97,7 +97,8 @@
     ${BOOST_SOURCES_DIR}/libs/system/src/error_code.cpp
     )
 
-  if ("${CMAKE_SYSTEM_VERSION}" STREQUAL "LinuxStandardBase")
+  if ("${CMAKE_SYSTEM_VERSION}" STREQUAL "LinuxStandardBase" OR
+      "${CMAKE_SYSTEM_NAME}" STREQUAL "Android")
     add_definitions(
       -DBOOST_SYSTEM_USE_STRERROR=1
       )
@@ -148,7 +149,10 @@
       )
 
   elseif (CMAKE_SYSTEM_NAME STREQUAL "Emscripten")
-    # No support for threads in WebAssembly
+    # No support for threads in asm.js/WebAssembly
+
+  elseif (CMAKE_SYSTEM_NAME STREQUAL "Android")
+    # No support for threads in Android
 
   else()
     message(FATAL_ERROR "Support your platform here")
@@ -181,7 +185,8 @@
 
   if (CMAKE_SYSTEM_NAME STREQUAL "PNaCl" OR
       CMAKE_SYSTEM_NAME STREQUAL "NaCl32" OR
-      CMAKE_SYSTEM_NAME STREQUAL "NaCl64")
+      CMAKE_SYSTEM_NAME STREQUAL "NaCl64" OR
+      CMAKE_SYSTEM_NAME STREQUAL "Android")
     # boost::filesystem is not available on PNaCl
     add_definitions(
       -DBOOST_HAS_FILESYSTEM_V3=0